# Normal

$ zzdicantonimos alto
Contrário de grande:
 baixo pequeno raso diminuto anão miúdo nanico tacanho

Contrário de superior:
 inferior último ínfero pior péssimo

Contrário de eminente:
 indigno torpe vil sórdido reles ordinário ignóbil rasteiro tratante

Contrário de excessivo:
 módico modesto reduzido razoável econômico

Contrário de sério:
 insignificante desimportante irrelevante irrisório leve desprezível

Contrário de erguido:
 caído flácido murcho mole

Contrário de incompreensível:
 acessível compreensível fácil simples inteligível descomplicado perceptível cognoscível claro cristalino

Contrário de arrojado:
 medroso covarde temeroso frouxo

Contrário de agudo:
 grave fraco abafado

Contrário de afastado:
 próximo perto aproximado junto pegado vizinho

Contrário de cimo:
 base falda sopé pé aba socairo

Contrário de bêbado:
 sóbrio abstêmico abstinente
$

# Palavra com acentos

$ zzdicantonimos folgazão
 introvertido sério infeliz tristonho rancoroso
$

# Palavra não encontrada

$ zzdicantonimos foobar
$

# Sem argumentos

$ zzdicantonimos        #=> --regex ^Uso:
